/*******************************************************************************
 * Copyright 2007 SWTBot, http://swtbot.org/
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package net.sf.swtbot.eclipse.finder.resolver;

import java.util.ArrayList;
import java.util.List;

import net.sf.swtbot.resolvers.IChildrenResolver;
import net.sf.swtbot.resolvers.IParentResolver;

import org.eclipse.swt.custom.CTabItem;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Widget;
import org.eclipse.ui.internal.presentations.PresentablePart;
import org.eclipse.ui.internal.presentations.util.WidgetTabItem;

/**
 * @author Ketan Padegaonkar &lt;KetanPadegaonkar [at] gmail [dot] com&gt;
 * @version $Id: EclipseCTabItemResolver.java 301 2008-02-04 10:40:18Z kpadegaonkar $
 */
public class EclipseCTabItemResolver implements IChildrenResolver, IParentResolver {

	public boolean hasChildren(Widget w) {
		return !canResolve(w) ? false : !getChildren(w).isEmpty();
	}

	public List getChildren(Widget w) {
		CTabItem cTabItem = (CTabItem) w;
		Object data = cTabItem.getData();
		List findControls = new ArrayList();
		if (data instanceof WidgetTabItem) {
			WidgetTabItem tabItem = (WidgetTabItem) data;
			Object presentablePart = tabItem.getData();
			if (presentablePart instanceof PresentablePart) {
				Control control = ((PresentablePart) presentablePart).getPane().getControl();
				if (control != null)
					findControls.add(control);
			}
		}
		return findControls;
	}

	public boolean canResolve(Widget w) {
		return w instanceof CTabItem;
	}

	public Class[] getResolvableClasses() {
		return new Class[] { CTabItem.class };
	}

	public Widget getParent(Widget w) {
		return canResolve(w) ? ((CTabItem) w).getParent() : null;
	}

	public boolean hasParent(Widget w) {
		return getParent(w) != null;
	}

}
