/*******************************************************************************
 * Copyright 2007 SWTBot, http://swtbot.org/
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package net.sf.swtbot.eclipse.spy;

import net.sf.swtbot.resolvers.IChildrenResolver;
import net.sf.swtbot.resolvers.IParentResolver;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IAction;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.StyledText;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Listener;

/**
 * @author Ketan Padegaonkar &lt;KetanPadegaonkar [at] gmail [dot] com&gt;
 * @version $Id: EclipseSpy.java 267 2008-01-11 04:47:47Z kpadegaonkar $
 */
public class EclipseSpy {

	Action					actionMonitor;

	long					lastWidget;

	StyledText				output;

	Runnable				trackWidgets;

	private final Composite	parent;

	/**
	 * @param parent
	 * @param childrenResolver
	 * @param parentResolver
	 */
	public EclipseSpy(Composite parent, IChildrenResolver childrenResolver, IParentResolver parentResolver) {
		this.parent = parent;
		initialize(parent.getDisplay());
		trackWidgets = new EclipseWidgetTracker(this, childrenResolver, parentResolver);
	}

	private void createActionMonitor() {
		actionMonitor = new Action("Monitor", IAction.AS_CHECK_BOX) {
			public void run() {
				if (actionMonitor.isChecked()) {
					Display display = output.getDisplay();
					display.timerExec(100, trackWidgets);
				}
			}
		};

		actionMonitor.setToolTipText("Enable/Disable monitoring of widgets");
		actionMonitor.setChecked(false);
	}

	private void createOutputText() {
		output = new StyledText(parent, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL | SWT.READ_ONLY);
		output.setLayoutData(new GridData(GridData.FILL_HORIZONTAL, GridData.FILL_VERTICAL, true, true));
		output.setFont(new Font(Display.getCurrent(), "Courier New", 10, SWT.NONE));
	}

	private void hookAccelerator() {
		parent.getDisplay().addFilter(SWT.KeyDown, new Listener() {
			public void handleEvent(Event e) {
				if ((e.stateMask == SWT.CTRL) && (e.keyCode == SWT.SHIFT))
					if (actionMonitor.isChecked())
						actionMonitor.setChecked(false);
					else {
						actionMonitor.setChecked(true);
						actionMonitor.run();
					}
			}
		});

		// parent.getDisplay().addFilter(SWT.KeyDown, new SWTBotExecutionListener());
	}

	private void initialize(Display display) {
		createOutputText();
		createActionMonitor();
		hookAccelerator();
	}
}
